@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.c,v 1.62 2003/12/20 04:20:50 fuyu Exp $
+ * $Id: bbs_thread_ui.c,v 1.65 2003/12/21 17:22:13 fuyu Exp $
  */
 
 #include "config.h"
@@ -764,7 +764,8 @@ open_bbs_thread(OchushaApplication *application, OchushaBBSThread *thread,
     OchushaAsyncBuffer *buffer;
 
     thread_view = bbs_thread_view_new(thread);
-    /*      gtk_widget_show(thread_view); */
+    g_object_ref(G_OBJECT(thread_view));
+    gtk_object_sink(GTK_OBJECT(thread_view));
 
     job = G_NEW0(WorkerJob, 1);
     job_args = G_NEW0(BBSThreadJobArgs, 1);
@@ -779,7 +780,7 @@ open_bbs_thread(OchushaApplication *application, OchushaBBSThread *thread,
 #endif
 	G_FREE(job_args);
 	G_FREE(job);
-	gtk_object_sink(GTK_OBJECT(thread_view));
+	g_object_unref(G_OBJECT(thread_view));
 
 	BBS_THREAD_UI_UNLOCK;
 	return NULL;
@@ -827,6 +828,10 @@ open_bbs_thread(OchushaApplication *application, OchushaBBSThread *thread,
     g_object_ref(G_OBJECT(buffer));
     g_object_ref(G_OBJECT(tab_label));
     g_object_ref(G_OBJECT(thread_view));
+#if 0
+    fprintf(stderr, "#1: thread_view(%p)->ref_count=%d\n",
+	    thread_view, G_OBJECT(thread_view)->ref_count);
+#endif
     commit_job(job);
   }
   BBS_THREAD_UI_UNLOCK;
@@ -1300,6 +1305,53 @@ show_mailto(OchushaApplication *application, OchushaBBSThread *thread)
 }
 
 
+static void
+update_threadlist_entry_real(OchushaApplication *application,
+			     OchushaBBSThread *thread)
+{
+  PanedNotebook *board_view;
+  GtkWidget *scrolled_window;
+  ThreadlistView *threadlist_view;
+  PanedNotebook *boardlist = (PanedNotebook *)application->contents_window;
+
+  g_return_if_fail(boardlist != NULL && thread != NULL);
+
+  board_view = (PanedNotebook *)paned_notebook_get_item_view(boardlist,
+							     thread->board);
+
+  if (board_view == NULL)
+    return;	/* ĤɽƤʤ⤢ */
+
+  scrolled_window = paned_notebook_get_selector(board_view);
+
+  if (scrolled_window == NULL)
+    {
+      return;	/* ե륿ߤǥɽƤʤ
+		 * ⤢롣
+		 */
+    }
+
+  threadlist_view
+    = THREADLIST_VIEW(gtk_bin_get_child(GTK_BIN(scrolled_window)));
+
+  update_threadlist_entry_style(application, threadlist_view, thread);
+}
+
+
+static void
+update_threadlist_entry(OchushaApplication *application,
+			OchushaBBSThread *thread)
+{
+  PanedNotebook *boardlist = (PanedNotebook *)application->contents_window;
+
+  g_return_if_fail(boardlist != NULL && thread != NULL);
+
+  gdk_threads_enter();
+  update_threadlist_entry_real(application, thread);
+  gdk_threads_leave();
+}
+
+
 typedef struct _ScrollToMarkArgs
 {
   BBSThreadView *view;
@@ -1367,6 +1419,11 @@ bookmark_clicked_cb(GtkWidget *widget, BBSThreadView *view)
 static void
 bookmark_destroy_cb(GtkWidget *widget, BBSThreadGUIInfo *info)
 {
+  if (info->bookmark == widget)
+    info->bookmark = NULL;
+#if 0
+  fprintf(stderr, "bookmark(%p) destroyed.\n", widget);
+#endif
 }
 
 
@@ -1374,17 +1431,13 @@ static void
 insert_bookmark(BBSThreadView *view, OchushaBBSThread *thread, int res_num,
 		OchushaApplication *application)
 {
-  BBSThreadGUIInfo *info;
+  BBSThreadGUIInfo *info = ensure_bbs_thread_info(thread);
+  guint *offsets = info->offsets;
+  guint offsets_length = info->offsets_length;
   GtkWidget *bookmark;
-  guint *offsets;
-  guint offsets_length;
   int i;
   gchar *bookmark_text;
 
-  info = ensure_bbs_thread_info(thread);
-  offsets = info->offsets;
-  offsets_length = info->offsets_length;
-
   g_return_if_fail(res_num > 0 && res_num < offsets_length);
 
   if (info->bookmark != NULL && info->bookmark_response_number == res_num)
@@ -1455,7 +1508,7 @@ insert_bookmark(BBSThreadView *view, OchushaBBSThread *thread, int res_num,
   info->bookmark_response_number = res_num;
   info->bookmark = bookmark;
 
-  update_threadlist_entry(application, thread);
+  update_threadlist_entry_real(application, thread);
 }
 
 
@@ -1716,6 +1769,10 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
     g_object_unref(G_OBJECT(job_args->tab_label));
 
   g_object_unref(G_OBJECT(job_args->view));
+#if 0
+  fprintf(stderr, "#3: thread_view(%p)->ref_count=%d\n",
+	  job_args->view, G_OBJECT(job_args->view)->ref_count);
+#endif
 
   iconv_close(context.handler.converter);
 
@@ -3148,6 +3205,10 @@ refresh_thread(OchushaApplication *application, GtkWidget *widget,
     g_object_ref(G_OBJECT(buffer));
     g_object_ref(G_OBJECT(tab_label));
     g_object_ref(G_OBJECT(view));
+#if 0
+    fprintf(stderr, "#2: thread_view(%p)->ref_count=%d\n",
+	    view, G_OBJECT(view)->ref_count);
+#endif
     commit_job(job);
 
     if (old_buffer != NULL)
