@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.h,v 1.15 2003/12/16 14:50:33 fuyu Exp $
+ * $Id: bbs_thread_ui.h,v 1.17 2003/12/20 04:21:27 fuyu Exp $
  */
 
 #ifndef _BBSTHREAD_UI_H_
@@ -60,6 +60,9 @@ typedef struct _BBSThreadGUIInfo
   /* ߤΥ */
   int view_rank;
 
+  /* ߤΥ쥹ɽ */
+  int num_shown;
+
   /* ɽ(ThreadlistEntryFlagsORȤä) */
   int view_flags;
 
@@ -113,6 +116,9 @@ typedef struct _BBSThreadGUIInfo
 
   gboolean a_bone_by_content;
   gchar *a_bone_by_content_pattern;
+
+  guint bookmark_response_number;
+  GtkWidget *bookmark;
 } BBSThreadGUIInfo;
 
 
@@ -128,7 +134,7 @@ void refresh_thread(OchushaApplication *application, GtkWidget *widget,
 		    OchushaBBSThread *thread, IconLabel *tab_label);
 void go_to_the_first_response(GtkWidget *widget, OchushaBBSThread *thread);
 void go_to_the_last_response(GtkWidget *widget, OchushaBBSThread *thread);
-void jump_to_new_comer_response(GtkWidget *widget, OchushaBBSThread *thread);
+void jump_to_bookmark(GtkWidget *widget, OchushaBBSThread *thread);
 
 void select_thread_view_font(OchushaApplication *application);
 void set_thread_view_font(const char *font_name);
