@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.c,v 1.29 2003/12/18 15:56:34 fuyu Exp $
+ * $Id: bbs_thread_view.c,v 1.30 2003/12/21 02:23:13 fuyu Exp $
  */
 
 #include "config.h"
@@ -502,6 +502,7 @@ bbs_thread_view_finalize(GObject *object)
 {
 #if 0
   BBSThreadView *view = BBS_THREAD_VIEW(object);
+  fprintf(stderr, "bbs_thread_view_finalize(%p)\n", object);
 #endif
 
   if (G_OBJECT_CLASS(parent_class)->finalize)
@@ -514,6 +515,10 @@ bbs_thread_view_destroy(GtkObject *object)
 {
   BBSThreadView *view = BBS_THREAD_VIEW(object);
 
+#if 0
+  fprintf(stderr, "bbs_thread_view_destroy(%p)\n", object);
+#endif
+
   if (view->text_buffer != NULL)
     {
       g_object_unref(G_OBJECT(view->text_buffer));
