@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.c,v 1.40 2003/12/19 03:14:24 fuyu Exp $
+ * $Id: boardlist_ui.c,v 1.43 2003/12/21 19:14:02 fuyu Exp $
  */
 
 #include "config.h"
@@ -303,6 +303,9 @@ initialize_boardlist(OchushaApplication *application)
   paned_notebook_set_minimum_tab_label_size(PANED_NOTEBOOK(application->contents_window), application->board_tab_minimum_size);
   paned_notebook_set_tooltips(PANED_NOTEBOOK(application->contents_window),
 			      application->board_tab_enable_tooltips);
+  paned_notebook_set_tab_policy(PANED_NOTEBOOK(application->contents_window),
+				application->board_tab_always_show
+				? GTK_POLICY_ALWAYS : GTK_POLICY_AUTOMATIC);
 
   toolbar = paned_notebook_get_toolbar(PANED_NOTEBOOK(application->contents_window));
 
@@ -322,6 +325,7 @@ initialize_boardlist(OchushaApplication *application)
 			   application,
 			   0);
   filter_button = gtk_toggle_button_new_with_label(_("Filter"));
+  GTK_WIDGET_UNSET_FLAGS(filter_button, GTK_CAN_FOCUS);
   gtk_widget_show(filter_button);
   application->filter_button = GTK_TOGGLE_BUTTON(filter_button);
   gtk_toolbar_prepend_widget(toolbar, filter_button,
@@ -883,42 +887,6 @@ fix_filter_button_state(OchushaApplication *application)
 }
 
 
-void
-update_threadlist_entry(OchushaApplication *application, OchushaBBSThread *thread)
-{
-  PanedNotebook *board_view;
-  GtkWidget *scrolled_window;
-  ThreadlistView *threadlist_view;
-  PanedNotebook *boardlist = (PanedNotebook *)application->contents_window;
-
-  g_return_if_fail(boardlist != NULL && thread != NULL);
-
-  gdk_threads_enter();
-  board_view = (PanedNotebook *)paned_notebook_get_item_view(boardlist,
-							     thread->board);
-
-  if (board_view == NULL)
-    goto finish_update;	/* ĤɽƤʤ⤢ */
-
-  scrolled_window = paned_notebook_get_selector(board_view);
-
-  if (scrolled_window == NULL)
-    {
-      goto finish_update;	/* ե륿ߤǥɽƤʤ
-				 * ⤢롣
-				 */
-    }
-
-  threadlist_view
-    = THREADLIST_VIEW(gtk_bin_get_child(GTK_BIN(scrolled_window)));
-
-  update_threadlist_entry_style(application, threadlist_view, thread);
-
- finish_update:
-  gdk_threads_leave();
-}
-
-
 static void
 filter_toggled_cb(GtkToggleButton *toggle_button,
 		  OchushaApplication *application)
