@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.h,v 1.8 2003/06/20 18:14:40 fuyu Exp $
+ * $Id: boardlist_ui.h,v 1.9 2003/12/21 17:22:13 fuyu Exp $
  */
 
 #ifndef _BOARDLIST_UI_H_
@@ -46,9 +46,6 @@ void refresh_boardlist(OchushaApplication *application);
 void redraw_boardlist(OchushaApplication *appliction);
 void finalize_boardlist(OchushaApplication *application);
 
-void update_threadlist_entry(OchushaApplication *application,
-			     OchushaBBSThread *thread);
-
 void open_current_board_properties(OchushaApplication *application);
 
 void refresh_current_threadlist(OchushaApplication *application);
