@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.c,v 1.79 2003/12/20 04:20:18 fuyu Exp $
+ * $Id: bulletin_board_ui.c,v 1.80 2003/12/21 02:23:13 fuyu Exp $
  */
 
 #include "config.h"
@@ -842,7 +842,7 @@ open_bulletin_board(OchushaApplication *application,
     if (info->threadlist_source_buffer != NULL)
       g_object_ref(G_OBJECT(info->threadlist_source_buffer));
 #if DEBUG_WIDGET
-    fprintf(stderr, "threadlist_view->ref_count=%d\n",
+    fprintf(stderr, "#1: threadlist_view->ref_count=%d\n",
 	    G_OBJECT(view)->ref_count);
 #endif
     commit_job(job);
@@ -1028,6 +1028,10 @@ refresh_threadlist_view(OchushaApplication *application,
     g_object_ref(G_OBJECT(info->threadlist_source_buffer));
     g_object_ref(G_OBJECT(tab_label));
     g_object_ref(G_OBJECT(threadlist_view));
+#if DEBUG_WIDGET
+    fprintf(stderr, "#2: threadlist_view->ref_count=%d\n",
+	    G_OBJECT(threadlist_view)->ref_count);
+#endif
     commit_job(job);
 
     g_object_unref(G_OBJECT(old_buffer));
@@ -1098,6 +1102,10 @@ redraw_threadlist_view(OchushaApplication *application,
     g_object_ref(G_OBJECT(info->threadlist_source_buffer));
     g_object_ref(G_OBJECT(tab_label));
     g_object_ref(G_OBJECT(threadlist_view));
+#if DEBUG_WIDGET
+    fprintf(stderr, "#3: threadlist_view->ref_count=%d\n",
+	    G_OBJECT(threadlist_view)->ref_count);
+#endif
     commit_job(job);
   }
   THREAD_LIST_UNLOCK;
@@ -1984,7 +1992,7 @@ finalize_bulletin_board_view(OchushaBulletinBoard *board, GtkWidget *widget)
       {
 	ThreadlistView *threadlist_view
 	  = THREADLIST_VIEW(gtk_bin_get_child(GTK_BIN(scrolled_window)));
-	fprintf(stderr, "finalize: threadlist_view->ref_count=%d\n",
+	fprintf(stderr, "#5: finalize: threadlist_view->ref_count=%d\n",
 		G_OBJECT(threadlist_view)->ref_count);
       }
   }
