@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.h,v 1.21 2003/12/16 18:00:54 fuyu Exp $
+ * $Id: bulletin_board_ui.h,v 1.23 2003/12/19 03:14:25 fuyu Exp $
  */
 
 #ifndef _BULLETIN_BOARD_UI_H_
@@ -125,6 +125,9 @@ void finalize_bulletin_board_view(OchushaBulletinBoard *board,
 void ochusha_open_thread(OchushaApplication *application,
 			 OchushaBulletinBoard *board, const char *thread_id,
 			 int res_num, gboolean in_tab);
+void ochusha_open_kako_thread(OchushaApplication *application,
+			      OchushaBulletinBoard *board, const char *url,
+			      gboolean in_tab);
 
 void write_response(OchushaApplication *application);
 
@@ -141,7 +144,7 @@ void update_threadlist_entry_style(OchushaApplication *application,
 
 void refresh_current_thread(OchushaApplication *application);
 void start_thread_search(OchushaApplication *application);
-void jump_to_new_comer_response_of_current_thread(OchushaApplication *application);
+void jump_to_bookmark_of_current_thread(OchushaApplication *application);
 void go_to_the_last_response_of_current_thread(OchushaApplication *application);
 void go_to_the_first_response_of_current_thread(OchushaApplication *application);
 
