@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: main.c,v 1.9 2003/12/06 02:38:59 fuyu Exp $
+ * $Id: main.c,v 1.10 2003/12/12 21:43:52 fuyu Exp $
  */
 
 #include "config.h"
@@ -36,6 +36,12 @@
 
 #include "ochusha_ui.h"
 
+#if HAVE_ONIG_ONIGPOSIX_H
+# include <onig/onigposix.h>
+#else
+# include <onigposix.h>
+#endif
+
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <libxml/parser.h>
@@ -59,6 +65,8 @@ main(int argc, char *argv[])
   init_memory_trace();
 #endif
 
+  reg_set_encoding(REG_ENCODING_UTF8);
+
   application = G_NEW0(OchushaApplication, 1);
   ochusha_config_prepare_home(&application->config);
 
