@@ -12,19 +12,22 @@ G_BEGIN_DECLS
 /* VOID:BOXED (marshal.list:2) */
 #define ochusha_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED
 
-/* VOID:INT (marshal.list:3) */
+/* VOID:ENUM (marshal.list:3) */
+#define ochusha_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM
+
+/* VOID:INT (marshal.list:4) */
 #define ochusha_marshal_VOID__INT	g_cclosure_marshal_VOID__INT
 
-/* VOID:OBJECT (marshal.list:4) */
+/* VOID:OBJECT (marshal.list:5) */
 #define ochusha_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT
 
-/* VOID:POINTER (marshal.list:5) */
+/* VOID:POINTER (marshal.list:6) */
 #define ochusha_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
 
-/* VOID:VOID (marshal.list:6) */
+/* VOID:VOID (marshal.list:7) */
 #define ochusha_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID
 
-/* VOID:ENUM,INT (marshal.list:7) */
+/* VOID:ENUM,INT (marshal.list:8) */
 extern void ochusha_marshal_VOID__ENUM_INT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -32,7 +35,7 @@ extern void ochusha_marshal_VOID__ENUM_INT (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:OBJECT,OBJECT (marshal.list:8) */
+/* VOID:OBJECT,OBJECT (marshal.list:9) */
 extern void ochusha_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -40,7 +43,7 @@ extern void ochusha_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
-/* VOID:OBJECT,BOOLEAN (marshal.list:9) */
+/* VOID:OBJECT,BOOLEAN (marshal.list:10) */
 extern void ochusha_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -48,7 +51,7 @@ extern void ochusha_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
 
-/* VOID:POINTER,OBJECT (marshal.list:10) */
+/* VOID:POINTER,OBJECT (marshal.list:11) */
 extern void ochusha_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -56,7 +59,7 @@ extern void ochusha_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
 
-/* VOID:BOXED,POINTER,STRING (marshal.list:11) */
+/* VOID:BOXED,POINTER,STRING (marshal.list:12) */
 extern void ochusha_marshal_VOID__BOXED_POINTER_STRING (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
@@ -64,7 +67,7 @@ extern void ochusha_marshal_VOID__BOXED_POINTER_STRING (GClosure     *closure,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);
 
-/* VOID:ENUM,INT,BOOLEAN (marshal.list:12) */
+/* VOID:ENUM,INT,BOOLEAN (marshal.list:13) */
 extern void ochusha_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
@@ -72,7 +75,7 @@ extern void ochusha_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);
 
-/* VOID:OBJECT,BOOLEAN,BOOLEAN (marshal.list:13) */
+/* VOID:OBJECT,BOOLEAN,BOOLEAN (marshal.list:14) */
 extern void ochusha_marshal_VOID__OBJECT_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
@@ -80,7 +83,7 @@ extern void ochusha_marshal_VOID__OBJECT_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);
 
-/* VOID:POINTER,POINTER,POINTER,POINTER (marshal.list:14) */
+/* VOID:POINTER,POINTER,POINTER,POINTER (marshal.list:15) */
 extern void ochusha_marshal_VOID__POINTER_POINTER_POINTER_POINTER (GClosure     *closure,
                                                                    GValue       *return_value,
                                                                    guint         n_param_values,
@@ -88,7 +91,7 @@ extern void ochusha_marshal_VOID__POINTER_POINTER_POINTER_POINTER (GClosure
                                                                    gpointer      invocation_hint,
                                                                    gpointer      marshal_data);
 
-/* BOOLEAN:ENUM,INT (marshal.list:15) */
+/* BOOLEAN:ENUM,INT (marshal.list:16) */
 extern void ochusha_marshal_BOOLEAN__ENUM_INT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -96,7 +99,7 @@ extern void ochusha_marshal_BOOLEAN__ENUM_INT (GClosure     *closure,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);
 
-/* BOOLEAN:OBJECT (marshal.list:16) */
+/* BOOLEAN:OBJECT (marshal.list:17) */
 extern void ochusha_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -104,7 +107,7 @@ extern void ochusha_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* BOOLEAN:BOXED,POINTER,STRING (marshal.list:17) */
+/* BOOLEAN:BOXED,POINTER,STRING (marshal.list:18) */
 extern void ochusha_marshal_BOOLEAN__BOXED_POINTER_STRING (GClosure     *closure,
                                                            GValue       *return_value,
                                                            guint         n_param_values,
@@ -112,7 +115,7 @@ extern void ochusha_marshal_BOOLEAN__BOXED_POINTER_STRING (GClosure     *closure
                                                            gpointer      invocation_hint,
                                                            gpointer      marshal_data);
 
-/* BOOLEAN:STRING,INT,BOOLEAN,BOOLEAN,BOOLEAN (marshal.list:18) */
+/* BOOLEAN:STRING,INT,BOOLEAN,BOOLEAN,BOOLEAN (marshal.list:19) */
 extern void ochusha_marshal_BOOLEAN__STRING_INT_BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                                          GValue       *return_value,
                                                                          guint         n_param_values,
