@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.c,v 1.52 2003/12/19 03:14:25 fuyu Exp $
+ * $Id: ochusha_ui.c,v 1.53 2003/12/21 04:36:08 fuyu Exp $
  */
 
 #include "config.h"
@@ -72,6 +72,7 @@
 
 #include "ochusha-banner.h"
 #include "ochusha-banner1.h"
+#include "ochusha-banner2.h"
 
 
 static void setup_ochusha_stock_items(void);
@@ -157,6 +158,7 @@ static GtkWidget *preference_dialog = NULL;
 static GtkWidget *about_dialog = NULL;
 static GdkPixbuf *banner_pixbuf = NULL;
 static GdkPixbuf *banner1_pixbuf = NULL;
+static GdkPixbuf *banner2_pixbuf = NULL;
 static GtkWidget *open_url_dialog = NULL;
 static GtkWidget *open_url_combo = NULL;
 static GtkWidget *open_url_in_tab_button = NULL;
@@ -335,6 +337,8 @@ ochusha_init_application(OchushaApplication *application)
     = gdk_pixbuf_new_from_inline(-1, ochusha_banner_inline, FALSE, NULL);
   banner1_pixbuf
     = gdk_pixbuf_new_from_inline(-1, ochusha_banner1_inline, FALSE, NULL);
+  banner2_pixbuf
+    = gdk_pixbuf_new_from_inline(-1, ochusha_banner2_inline, FALSE, NULL);
 
   configure_application(application);
 
@@ -2599,7 +2603,9 @@ open_about_dialog(OchushaApplication *application)
 	  time_t utc = time(NULL);
 	  localtime_r(&utc, &tm);
 
-	  if (tm.tm_year == 104 && tm.tm_yday < 7)
+	  if (tm.tm_yday >= 357 && tm.tm_yday <= 358)
+	    banner = banner2_pixbuf;
+	  else if (tm.tm_year == 104 && tm.tm_yday < 7)
 	    banner = banner1_pixbuf;
 	  else
 	    banner = banner_pixbuf;
