@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.h,v 1.34 2003/12/16 19:47:43 fuyu Exp $
+ * $Id: ochusha_ui.h,v 1.40 2003/12/20 04:38:44 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UI_H_
@@ -57,10 +57,6 @@
 #define OCHUSHA_DEFAULT_BOARDLIST_WIDTH					150
 #define OCHUSHA_DEFAULT_THREADLIST_HEIGHT				100
 
-#define OCHUSHA_DEFAULT_RENDERING_UNIT					300
-#define OCHUSHA_DEFAULT_WEIGHT_OF_THREADLIST_RENDERING			10
-#define OCHUSHA_DEFAULT_WEIGHT_OF_RESPONSE_RENDERING			20
-
 #define OCHUSHA_DEFAULT_BOARD_TAB_SHRINKABLE				FALSE
 #define OCHUSHA_DEFAULT_BOARD_TAB_MINIMUM_SIZE				80
 #define OCHUSHA_DEFAULT_BOARD_TAB_ENABLE_TOOLTIPS			FALSE
@@ -72,7 +68,7 @@
 #define OCHUSHA_DEFAULT_THREAD_TAB_ENABLE_TOOLTIPS			TRUE
 #define OCHUSHA_DEFAULT_SHOW_THREADLIST_ENTRY_WHEN_THREAD_SELECTED	FALSE
 
-#define OCHUSHA_DEFAULT_THREADLIST_VIEW_CONTENTS		"RMTNnUDL"
+#define OCHUSHA_DEFAULT_THREADLIST_VIEW_CONTENTS		"RMTVuDL"
 
 #define OCHUSHA_DEFAULT_ENABLE_POPUP_TITLE				FALSE
 #define OCHUSHA_DEFAULT_ENABLE_POPUP_RESPONSE				TRUE
@@ -158,7 +154,7 @@ struct _OchushaApplication
   GtkStatusbar *statusbar;
 
   GtkClipboard *clipboard;
-
+  GtkClipboard *clipboard_primary;
 
   GtkWidget *threadlist_search_window;
 
@@ -203,6 +199,9 @@ struct _OchushaApplication
   gboolean enable_transparent_a_bone;
   gboolean disable_popup_a_bone;
 
+  gboolean stick_bookmark;
+  gchar *bookmark_text;
+
 
   /* ΤΥǥե */
   ThreadViewMailtoMode show_mailto_mode;
