@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_view.c,v 1.32 2003/12/20 04:20:18 fuyu Exp $
+ * $Id: threadlist_view.c,v 1.34 2003/12/21 02:22:06 fuyu Exp $
  */
 
 #include "config.h"
@@ -1952,8 +1952,10 @@ text_set_num_of_responses_verbose(GtkTreeViewColumn *tree_column,
 		     -1);
 
   num_responses_available = MAX(num_responses, num_responses_got);
-  if (num_responses_available == num_responses_got || num_responses_got == 0)
+  if (num_responses_got == 0)
     snprintf(verbose_text, 64, "%d", num_responses_available);
+  else if (num_responses_got == num_responses_available)
+    snprintf(verbose_text, 64, "%d (0)", num_responses_available);
   else
     snprintf(verbose_text, 64, "%d (+%d)", num_responses_available,
 	     num_responses_available - num_responses_got);
@@ -2517,15 +2519,6 @@ threadlist_view_update_thread(ThreadlistView *view, OchushaBBSThread *thread,
 
   info = ensure_threadlist_info(thread);
 
-  if (info->threadlist_view != view)
-    {
-#if DEBUG_WIDGET	/* ΥƥȼΤĹ */
-      fprintf(stderr, "info->threadlist_view=%p, view=%p\n",
-	      info->threadlist_view, view);
-#endif
-      return;
-    }
-
   if (!gtk_list_store_iter_is_valid(GTK_LIST_STORE(view->model), &info->iter))
     {
       /* 줿ե륿ξ֤ѤäơiterŤʤäȤ롣 */
