@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_view.h,v 1.17 2003/12/05 08:40:54 fuyu Exp $
+ * $Id: threadlist_view.h,v 1.18 2003/12/20 04:20:18 fuyu Exp $
  */
 
 #ifndef _THREADLIST_VIEW_H_
@@ -82,8 +82,11 @@ struct _ThreadlistView
   GtkTreeViewColumn *mark_column;
   GtkTreeViewColumn *title_column;
   GtkTreeViewColumn *n_res_column;
-  GtkTreeViewColumn *n_read_column;
+  GtkTreeViewColumn *n_got_column;
+  GtkTreeViewColumn *n_ungot_column;
+  GtkTreeViewColumn *n_shown_column;
   GtkTreeViewColumn *n_unread_column;
+  GtkTreeViewColumn *n_res_verbose_column;
   GtkTreeViewColumn *rank_diff_column;
   GtkTreeViewColumn *last_modified_column;
 
@@ -93,10 +96,10 @@ struct _ThreadlistView
 
   /* Ϣ */
   gboolean (*title_match_func)(const gchar *title, gpointer search_data);
-  gint last_search_position;
+  int last_search_position;
   GtkTreePath *last_path;
 
-  gint last_rank_diff;
+  int last_rank_diff;
 
   OchushaBBSThread *recently_pointed_thread;
 
@@ -156,9 +159,9 @@ struct _ThreadlistViewClass
   gboolean (*interactive_search)(ThreadlistView *threadlist_view,
 				 ThreadlistSearchAction search_action);
 
-  void (*do_on_selection)(ThreadlistView *threadlist_view, gint what_to_do);
+  void (*do_on_selection)(ThreadlistView *threadlist_view, int what_to_do);
   void (*do_on_thread_at_cursor)(ThreadlistView *threadlist_view,
-				 gint what_to_do);
+				 int what_to_do);
 };
 
 
@@ -210,8 +213,11 @@ void threadlist_view_append_rank(ThreadlistView *view);
 void threadlist_view_append_mark(ThreadlistView *view);
 void threadlist_view_append_title(ThreadlistView *view);
 void threadlist_view_append_number_of_responses(ThreadlistView *view);
-void threadlist_view_append_number_of_responses_read(ThreadlistView *view);
+void threadlist_view_append_number_of_responses_got(ThreadlistView *view);
+void threadlist_view_append_number_of_responses_ungot(ThreadlistView *view);
+void threadlist_view_append_number_of_responses_shown(ThreadlistView *view);
 void threadlist_view_append_number_of_responses_unread(ThreadlistView *view);
+void threadlist_view_append_number_of_responses_verbose(ThreadlistView *view);
 void threadlist_view_append_rank_difference(ThreadlistView *view);
 void threadlist_view_append_last_modified(ThreadlistView *view);
 
@@ -222,9 +228,11 @@ void threadlist_view_close(ThreadlistView *view,
 			   OchushaBBSThread *last_thread);
 void threadlist_view_append_thread(ThreadlistView *view,
 				   OchushaBBSThread *thread,
-				   gint last_rank, gint new_rank);
+				   int num_shown, int num_unread,
+				   int last_rank, int new_rank);
 void threadlist_view_update_thread(ThreadlistView *view,
-				   OchushaBBSThread *thread);
+				   OchushaBBSThread *thread,
+				   int num_shown, int num_unread);
 void threadlist_view_update_thread_visual(ThreadlistView *view,
 				OchushaBBSThread *thread,
 				ThreadlistEntryVisualParameter *parameter);
