@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: gziputils.c,v 1.5 2003/12/15 17:15:11 fuyu Exp $
+ * $Id: gziputils.c,v 1.6 2003/12/19 03:13:49 fuyu Exp $
  */
 
 #include "config.h"
@@ -180,8 +180,7 @@ gzip_buffer_append_data(GzipBuffer *buffer, const char *data,
 
       /* ȤꤢϤ2̤ܰ;͵ */
       if (!ochusha_async_buffer_ensure_free_space(buffer->output,
-						  zstream->avail_in * 2,
-						  "gziputils.c: gzip_buffer_append_data"))
+						  zstream->avail_in * 2))
 	{
 #if DEBUG_ASYNC_BUFFER_MOST
 	  fprintf(stderr, "gzip_buffer_append_data: buffer may have been terminated.\n");
@@ -197,8 +196,7 @@ gzip_buffer_append_data(GzipBuffer *buffer, const char *data,
       result = inflate(zstream, Z_NO_FLUSH);
       total_length += (initial_space - zstream->avail_out);
 
-      if (!ochusha_async_buffer_update_length(buffer->output, total_length,
-				"gziputils.c: gzip_buffer_append_data"))
+      if (!ochusha_async_buffer_update_length(buffer->output, total_length))
 	{
 #if DEBUG_ASYNC_BUFFER_MOST
 	  fprintf(stderr, "gzip_buffer_append_data: buffer may have been terminated after update length.\n");
