@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.c,v 1.17 2003/12/15 17:22:29 fuyu Exp $
+ * $Id: ochusha_bbs_thread.c,v 1.18 2003/12/19 03:13:49 fuyu Exp $
  */
 
 #include "config.h"
@@ -604,26 +604,45 @@ ochusha_bbs_thread_read_threadlist_element(OchushaBBSThread *thread,
  * threadlist.xmlϢ
  */
 #define OUTPUT_THREAD_ATTRIBUTE_INT(file, thread, attribute)		\
-  fprintf(file,								\
-	  "      <attribute name=\"" #attribute	"\">\n"			\
-	  "        <int val=\"%d\"/>\n"					\
-	  "      </attribute>\n", (thread)->attribute)
+  do									\
+    {									\
+      if ((thread)->attribute)						\
+	{								\
+	  fprintf(file,							\
+		  "      <attribute name=\"" #attribute	"\">\n"		\
+		  "        <int val=\"%d\"/>\n"				\
+		  "      </attribute>\n", (thread)->attribute);		\
+	}								\
+    } while (0)
+
 
 #define OUTPUT_THREAD_ATTRIBUTE_BOOLEAN(file, thread, attribute)	\
-  fprintf(file,								\
-	  "      <attribute name=\"" #attribute	"\">\n"			\
-	  "        <boolean val=\"%s\"/>\n"				\
-	  "      </attribute>\n", (thread)->attribute ? "true" : "false")
+  do									\
+    {									\
+      if ((thread)->attribute)						\
+	{								\
+	  fprintf(file,							\
+		  "      <attribute name=\"" #attribute	"\">\n"		\
+		  "        <boolean val=\"%s\"/>\n"			\
+		  "      </attribute>\n",				\
+		  (thread)->attribute ? "true" : "false");		\
+	}								\
+    } while (0)
+
 
 #define OUTPUT_THREAD_ATTRIBUTE_STRING(file, thread, attribute)		\
-  do {									\
-    gchar *text = g_markup_escape_text((thread)->attribute, -1);	\
-    fprintf(file,							\
-	  "      <attribute name=\"" #attribute	"\">\n"			\
-	  "        <string>%s</string>\n"				\
-	  "      </attribute>\n", text);				\
-    g_free(text);							\
-  } while (0)
+  do									\
+    {									\
+      if ((thread)->attribute)						\
+	{								\
+	  gchar *text = g_markup_escape_text((thread)->attribute, -1);	\
+	  fprintf(file,							\
+		  "      <attribute name=\"" #attribute	"\">\n"		\
+		  "        <string>%s</string>\n"			\
+		  "      </attribute>\n", text);			\
+	  g_free(text);							\
+	}								\
+    } while (0)
 
 
 static void
