@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_2ch.c,v 1.24 2003/12/16 17:25:59 fuyu Exp $
+ * $Id: ochusha_board_2ch.c,v 1.25 2003/12/19 03:12:58 fuyu Exp $
  */
 
 #include "config.h"
@@ -46,9 +46,6 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <sys/types.h>
-#include <sys/mman.h>
-
 #include <time.h>
 #include <unistd.h>
 
@@ -88,6 +85,10 @@ static OchushaBBSThread *ochusha_board_2ch_thread_new(
 static OchushaBBSThread *ochusha_board_2ch_lookup_thread_by_url(
 						OchushaBulletinBoard *board,
 						const char *url);
+static OchushaBBSThread *ochusha_board_2ch_lookup_kako_thread_by_url(
+						OchushaBulletinBoard *board,
+						OchushaNetworkBroker *broker,
+						const char *url);
 static OchushaAsyncBuffer *ochusha_board_2ch_get_threadlist_source(
 					OchushaBulletinBoard *board,
 					OchushaNetworkBroker *broker,
@@ -157,6 +158,8 @@ ochusha_board_2ch_class_init(OchushaBoard2chClass *klass)
   b_class->generate_board_id = ochusha_board_2ch_generate_board_id;
   b_class->thread_new = ochusha_board_2ch_thread_new;
   b_class->lookup_thread_by_url = ochusha_board_2ch_lookup_thread_by_url;
+  b_class->lookup_kako_thread_by_url
+    = ochusha_board_2ch_lookup_kako_thread_by_url;
   b_class->get_threadlist_source = ochusha_board_2ch_get_threadlist_source;
   b_class->refresh_threadlist = ochusha_board_2ch_refresh_threadlist;
 
@@ -280,13 +283,6 @@ ochusha_board_2ch_get_subject_txt_encoding(OchushaBulletinBoard *board)
 }
 
 
-static void
-munmap_when_finished(OchushaAsyncBuffer *buffer)
-{
-  munmap((void *)buffer->buffer, buffer->length);
-}
-
-
 static gboolean
 recover_title(OchushaBBSThread *thread, const char *title, gpointer unused)
 {
@@ -366,31 +362,21 @@ ochusha_board_2ch_recover_threadlist(OchushaBulletinBoard *board,
 	      int fd = ochusha_config_open_file(config, path, O_RDONLY);
 	      if (fd >= 0)
 		{
-		  off_t len;
-		  char *buf;
-
-		  len = lseek(fd, 0, SEEK_END);
-		  buf = mmap(NULL, len, PROT_READ, MAP_NOCORE | MAP_PRIVATE,
-			     fd, 0);
-		  close(fd);
-		  if (buf != MAP_FAILED)
-		    {
-		      OchushaAsyncBuffer *dat_buffer
-			= ochusha_async_buffer_new(buf, len,
-						   munmap_when_finished);
-		      thread = ochusha_bulletin_board_bbs_thread_new(board, id,
-								     NULL);
-		      ochusha_bbs_thread_parse_responses(thread,
-							 dat_buffer,
-							 0, 1, TRUE,
-							 recover_title,
-							 NULL, NULL, NULL,
-							 NULL);
-		      g_object_unref(dat_buffer);
-		      thread->number_of_responses_read = 1;
-		      board->thread_list = g_slist_append(board->thread_list,
-							  thread);
-		    }
+		  OchushaAsyncBuffer *dat_buffer
+		    = ochusha_async_buffer_new_with_file_mmap(fd);
+		  ochusha_async_buffer_fix(dat_buffer);
+		  thread = ochusha_bulletin_board_bbs_thread_new(board, id,
+								 NULL);
+		  ochusha_bbs_thread_parse_responses(thread,
+						     dat_buffer,
+						     0, 1, TRUE,
+						     recover_title,
+						     NULL, NULL, NULL,
+						     NULL);
+		  g_object_unref(dat_buffer);
+		  thread->number_of_responses_read = 1;
+		  board->thread_list = g_slist_append(board->thread_list,
+						      thread);
 		}
 	    }
 	}
@@ -471,14 +457,31 @@ ochusha_board_2ch_lookup_thread_by_url(OchushaBulletinBoard *board,
   OchushaBBSThread *thread = NULL;
   char *board_url = NULL;
   char *thread_id = NULL;
+  gboolean is_kako_html = FALSE;
 
   if (ochusha_utils_2ch_check_url(url, &board_url, NULL, NULL, &thread_id,
-				  NULL, NULL))
+				  NULL, NULL, &is_kako_html))
     {
-      if (thread_id != NULL
-	  && g_ascii_strcasecmp(board->base_url, board_url) == 0)
-	thread = ochusha_bulletin_board_lookup_bbs_thread_by_id(board,
-								thread_id);
+      if (thread_id != NULL)
+	{
+#if 0	/* ǤƱ */
+	  if (is_kako_html)
+	    {
+	      /* TODO: ФΥåˤ⤦֤ */
+	      if (g_ascii_strcasecmp(board->base_url, board_url) == 0)
+		thread
+		  = ochusha_bulletin_board_lookup_bbs_thread_by_id(board,
+								   thread_id);
+	    }
+	  else
+#endif
+	    {
+	      if (g_ascii_strcasecmp(board->base_url, board_url) == 0)
+		thread
+		  = ochusha_bulletin_board_lookup_bbs_thread_by_id(board,
+								   thread_id);
+	    }
+	}
     }
 
   if (board_url != NULL)
@@ -491,6 +494,64 @@ ochusha_board_2ch_lookup_thread_by_url(OchushaBulletinBoard *board,
 }
 
 
+static OchushaBBSThread *
+ochusha_board_2ch_lookup_kako_thread_by_url(OchushaBulletinBoard *board,
+					    OchushaNetworkBroker *broker,
+					    const char *url)
+{
+  OchushaBBSThread *thread = NULL;
+  char *thread_id = NULL;
+  gboolean is_kako_html = FALSE;
+
+  g_return_val_if_fail(OCHUSHA_IS_BOARD_2CH(board)
+		       && OCHUSHA_IS_NETWORK_BROKER(broker)
+		       && url != NULL, NULL);
+
+  if (ochusha_utils_2ch_check_url(url, NULL, NULL, NULL, &thread_id,
+				  NULL, NULL, &is_kako_html))
+    {
+      if (thread_id != NULL)
+	{
+	  OchushaAsyncBuffer *dat_buffer;
+	  OchushaThread2ch *thread_2ch;
+
+	  thread = ochusha_bulletin_board_bbs_thread_new(board, thread_id,
+							 NULL);
+	  thread_2ch = OCHUSHA_THREAD_2CH(thread);
+	  ochusha_thread_2ch_set_kako_html_url(thread_2ch, url);
+	  dat_buffer = ochusha_bbs_thread_get_responses_source(thread, broker,
+					OCHUSHA_NETWORK_BROKER_CACHE_AS_IS);
+	  if (dat_buffer != NULL)
+	    {
+	      ochusha_bbs_thread_parse_responses(thread,
+						 dat_buffer,
+						 0, -1, FALSE,
+						 recover_title,
+						 NULL, NULL, NULL, NULL);
+	      ochusha_async_buffer_suspend(dat_buffer);
+	      ochusha_async_buffer_terminate(dat_buffer);
+	      g_object_unref(dat_buffer);
+
+	      if (thread->title != NULL)
+		{
+		  thread->number_of_responses_read = 1;
+		  board->thread_list = g_slist_append(board->thread_list,
+						      thread);
+		}
+	      else
+		{
+		  g_object_unref(thread);
+		  thread = NULL;
+		}
+	    }
+	  G_FREE(thread_id);
+	}
+    }
+
+  return thread;
+}
+
+
 static const char *
 ochusha_board_2ch_get_response_character_encoding(OchushaBulletinBoard *board)
 {
@@ -893,7 +954,7 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
       converter_helper = NULL;
     }
 
-  if (!ochusha_async_buffer_active_ref(buffer, "ochusha_board_2ch.c: ochusha_board_2ch_refresh_threadlist"))
+  if (!ochusha_async_buffer_active_ref(buffer))
     {
 #if DEBUG_ASYNC_BUFFER_MOST
       fprintf(stderr, "buffer has been terminated.\n");
@@ -1021,7 +1082,7 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 	    break;
 	  }
 
-	if (!ochusha_async_buffer_wait(buffer, "ochusha_board_2ch.c: ochusha_board_2ch_refresh_threadlist"))
+	if (!ochusha_async_buffer_wait(buffer))
 	  {
 #if DEBUG_ASYNC_BUFFER_MOST
 	    fprintf(stderr, "buffer has been terminated.\n");
@@ -1058,7 +1119,7 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 	}
     }
 
-  ochusha_async_buffer_active_unref(buffer, "ochusha_board_2ch.c: ochusha_board_2ch_refresh_threadlist");
+  ochusha_async_buffer_active_unref(buffer);
 
   if (result)
     {
