@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_jbbs.c,v 1.5 2003/12/14 16:10:28 fuyu Exp $
+ * $Id: ochusha_board_jbbs.c,v 1.6 2003/12/19 03:13:49 fuyu Exp $
  */
 
 #include "config.h"
@@ -722,7 +722,7 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
       converter_helper = NULL;
     }
 
-  if (!ochusha_async_buffer_active_ref(buffer, "ochusha_board_2ch.c: ochusha_board_2ch_refresh_threadlist"))
+  if (!ochusha_async_buffer_active_ref(buffer))
     {
 #if DEBUG_ASYNC_BUFFER_MOST
       fprintf(stderr, "buffer has been terminated.\n");
@@ -850,7 +850,7 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 	    break;
 	  }
 
-	if (!ochusha_async_buffer_wait(buffer, "ochusha_board_2ch.c: ochusha_board_2ch_refresh_threadlist"))
+	if (!ochusha_async_buffer_wait(buffer))
 	  {
 #if DEBUG_ASYNC_BUFFER_MOST
 	    fprintf(stderr, "buffer has been terminated.\n");
@@ -887,7 +887,7 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 	}
     }
 
-  ochusha_async_buffer_active_unref(buffer, "ochusha_board_2ch.c: ochusha_board_2ch_refresh_threadlist");
+  ochusha_async_buffer_active_unref(buffer);
 
   if (result)
     {
@@ -970,7 +970,7 @@ refresh_threadlist_by_subback_html(OchushaBulletinBoard *board,
     regfree(&threadlist_entry_pattern);
   g_return_val_if_fail(converter != (iconv_t)-1, FALSE);
 
-  if (!ochusha_async_buffer_active_ref(buffer, "ochusha_board_2ch.c: ochusha_board_2ch_refresh_threadlist"))
+  if (!ochusha_async_buffer_active_ref(buffer))
     {
 #if DEBUG_ASYNC_BUFFER_MOST
       fprintf(stderr, "buffer has been terminated.\n");
@@ -1074,7 +1074,7 @@ refresh_threadlist_by_subback_html(OchushaBulletinBoard *board,
 	    break;
 	  }
 
-	if (!ochusha_async_buffer_wait(buffer, "ochusha_board_2ch.c: ochusha_board_2ch_refresh_threadlist"))
+	if (!ochusha_async_buffer_wait(buffer))
 	  {
 #if DEBUG_ASYNC_BUFFER_MOST
 	    fprintf(stderr, "buffer has been terminated.\n");
@@ -1111,7 +1111,7 @@ refresh_threadlist_by_subback_html(OchushaBulletinBoard *board,
 	}
     }
 
-  ochusha_async_buffer_active_unref(buffer, "ochusha_board_2ch.c: ochusha_board_2ch_refresh_threadlist");
+  ochusha_async_buffer_active_unref(buffer);
 
   if (result)
     {
