@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bulletin_board.c,v 1.19 2003/12/16 17:25:59 fuyu Exp $
+ * $Id: ochusha_bulletin_board.c,v 1.20 2003/12/19 03:13:49 fuyu Exp $
  */
 
 #include "config.h"
@@ -198,6 +198,7 @@ ochusha_bulletin_board_class_init(OchushaBulletinBoardClass *klass)
   klass->generate_board_id = ochusha_bulletin_board_generate_board_id;
   klass->thread_new = NULL;
   klass->lookup_thread_by_url = NULL;
+  klass->lookup_kako_thread_by_url = NULL;
   klass->get_threadlist_source = NULL;
   klass->refresh_threadlist = NULL;
   klass->preview_new_thread = NULL;
@@ -541,6 +542,23 @@ ochusha_bulletin_board_lookup_bbs_thread_by_url(OchushaBulletinBoard *board,
 }
 
 
+OchushaBBSThread *
+ochusha_bulletin_board_lookup_kako_thread_by_url(OchushaBulletinBoard *board,
+						 OchushaNetworkBroker *broker,
+						 const char *url)
+{
+  OchushaBulletinBoardClass *klass;
+
+  g_return_val_if_fail(OCHUSHA_IS_BULLETIN_BOARD(board) && url != NULL,
+		       NULL);
+
+  klass = OCHUSHA_BULLETIN_BOARD_GET_CLASS(board);
+  g_return_val_if_fail(klass->lookup_kako_thread_by_url != NULL, NULL);
+
+  return (*klass->lookup_kako_thread_by_url)(board, broker, url);
+}
+
+
 OchushaAsyncBuffer *
 ochusha_bulletin_board_get_threadlist_source(OchushaBulletinBoard *board,
 					OchushaNetworkBroker *broker,
@@ -678,26 +696,44 @@ ochusha_bulletin_board_create_new_thread(OchushaBulletinBoard *board,
  * boardlist.xmlϢ
  */
 #define OUTPUT_BOARD_ATTRIBUTE_BOOLEAN(file, board, attribute)		\
-  fprintf(file,								\
-	  "        <attribute name=\"" #attribute	"\">\n"		\
-	  "          <boolean val=\"%s\"/>\n"				\
-	  "        </attribute>\n",					\
-	  (board)->attribute ? "true" : "false")
+  do									\
+    {									\
+      if ((board)->attribute)						\
+	{								\
+	  fprintf(file,							\
+		  "        <attribute name=\"" #attribute "\">\n"	\
+		  "          <boolean val=\"%s\"/>\n"			\
+		  "        </attribute>\n",				\
+		  (board)->attribute ? "true" : "false");		\
+	}								\
+    } while (0)
+
 
 #define OUTPUT_BOARD_ATTRIBUTE_INT(file, board, attribute)		\
-  fprintf(file,								\
-	  "        <attribute name=\"" #attribute	"\">\n"		\
-	  "          <int val=\"%d\"/>\n"				\
-	  "        </attribute>\n", (board)->attribute)
+  do									\
+    {									\
+      if ((board)->attribute)						\
+	{								\
+	  fprintf(file,							\
+		  "        <attribute name=\"" #attribute "\">\n"	\
+		  "          <int val=\"%d\"/>\n"			\
+		  "        </attribute>\n", (board)->attribute);	\
+	}								\
+    } while (0)
+
 
 #define OUTPUT_BOARD_ATTRIBUTE_STRING(file, board, attribute)		\
-  do {									\
-    gchar *text = g_markup_escape_text((board)->attribute, -1);		\
-    fprintf(file,							\
-	  "        <attribute name=\"" #attribute	"\">\n"		\
-	  "          <string>%s</string>\n"				\
-	  "        </attribute>\n", text);				\
-    g_free(text);							\
+  do									\
+    {									\
+      if ((board)->attribute)						\
+	{								\
+	  gchar *text = g_markup_escape_text((board)->attribute, -1);	\
+	  fprintf(file,							\
+		  "        <attribute name=\"" #attribute "\">\n"	\
+		  "          <string>%s</string>\n"			\
+		  "        </attribute>\n", text);			\
+	  g_free(text);							\
+	}								\
   } while (0)
 
 
