@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.c,v 1.44 2003/12/20 04:16:47 fuyu Exp $
+ * $Id: ochusha_thread_2ch.c,v 1.47 2003/12/21 18:36:13 fuyu Exp $
  */
 
 #include "config.h"
@@ -47,8 +47,7 @@
 #define DEBUG_DAT	0
 #define DEBUG_DAT_MOST	0
 
-#define ANALYSIS_INTERVAL	100
-#define ENABLE_MODEST_PARSING	1
+#define ANALYSIS_INTERVAL	20
 
 
 static void ochusha_thread_2ch_class_init(OchushaThread2chClass *klass);
@@ -716,7 +715,6 @@ extract_2ch_response(char *start_pos, char *eol_pos,
 }
 
 
-#if ENABLE_MODEST_PARSING
 static gboolean
 advance_parsing(gpointer data)
 {
@@ -724,7 +722,6 @@ advance_parsing(gpointer data)
   g_object_unref((GObject *)data);
   return FALSE;
 }
-#endif
 
 
 /*
@@ -854,11 +851,7 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 #endif
 	while (rest_of_data > 0
 	       && (rest_of_responses > 0 || rest_of_responses == -1)
-#if ENABLE_MODEST_PARSING
 	       && interval-- > 0
-#else
-	       && (buffer_fixed || interval-- > 0)
-#endif
 	       && (eol_pos = memchr(cur_pos, '\n', rest_of_data)) != NULL)
 	  {
 	    OchushaBBSResponse response = { NULL, NULL, NULL, NULL };
@@ -893,7 +886,7 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 		  result = (*start_thread_cb)(thread, title, callback_data);
 		G_FREE(title);
 		if (!result)
-		  break;
+		  goto terminated;
 	      }
 	    responses[i] = offset;
 
@@ -940,7 +933,7 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 		if (rest_of_responses != -1)
 		  rest_of_responses--;
 		if (!result)
-		  break;
+		  goto terminated;
 	      }
 
 	    offset = (eol_pos + 1) - buffer_top;
@@ -969,6 +962,8 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 	      G_FREE((gpointer)response.date_id);
 	    if (response.content != NULL)
 	      G_FREE((gpointer)response.content);
+
+	    eol_pos = NULL;
 	  }
 
 	if (!buffer_fixed && buffer->fixed)
@@ -978,8 +973,8 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 	    continue;
 	  }
 
-	if (buffer_fixed && eol_pos == NULL)
-	  break;
+	if (buffer_fixed && eol_pos == NULL && interval > 0)
+	  goto terminated;
 
 	if (interval > 0)
 	  {
@@ -987,11 +982,8 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 	     * ɤ٤ǡʤ硣
 	     */
 	    unsigned int old_len = buffer->length;
-#if COUNT_FAKE_SIGNAL	/* ¸ */
-	    int wait_count = 0;
-#endif
 	    if (no_wait)
-	      break;	/* ξ */
+	      goto terminated;	/* ξ */
 
 	    if (ochusha_async_buffer_is_busy(buffer))
 	      do {
@@ -1002,19 +994,10 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 #endif
 		    goto terminated;
 		  }
-#if COUNT_FAKE_SIGNAL	/* ¸ */
-		wait_count++;
-#endif
 	      } while (buffer->length == old_len && !buffer->fixed);
-
-#if COUNT_FAKE_SIGNAL	/* ¸ */
-	    if (wait_count > 0)
-	      fprintf(stderr, "wait_count=%d\n", wait_count);
-#endif
 	  }
 	else
 	  {
-#if ENABLE_MODEST_PARSING
 	    if (ochusha_async_buffer_is_busy(buffer))
 	      {
 		/*
@@ -1035,15 +1018,6 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 		if (!ochusha_async_buffer_wait(buffer))
 		  goto terminated;
 	      }
-#else
-	    /*
-	     * buffer˥륹åɤsuspend/terminate
-	     * ȿ뤿˥å
-	     */
-	    if (ochusha_async_buffer_is_busy(buffer)
-		&& !ochusha_async_buffer_wait(buffer))
-	      goto terminated;
-#endif
 	  }
 	interval = ANALYSIS_INTERVAL;
 
