@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_jbbs.c,v 1.14 2003/12/20 04:19:36 fuyu Exp $
+ * $Id: ochusha_thread_jbbs.c,v 1.17 2003/12/21 18:36:13 fuyu Exp $
  */
 
 #include "config.h"
@@ -59,8 +59,7 @@
 #define DEBUG_DAT	0
 #define DEBUG_DAT_MOST	0
 
-#define ANALYSIS_INTERVAL	100
-#define ENABLE_MODEST_PARSING	1
+#define ANALYSIS_INTERVAL	20
 
 
 static void ochusha_thread_jbbs_class_init(OchushaThreadJBBSClass *klass);
@@ -427,7 +426,6 @@ extract_jbbs_response(char *start_pos, char *eol_pos,
 }
 
 
-#if ENABLE_MODEST_PARSING
 static gboolean
 advance_parsing(gpointer data)
 {
@@ -435,7 +433,6 @@ advance_parsing(gpointer data)
   g_object_unref((GObject *)data);
   return FALSE;
 }
-#endif
 
 
 /*
@@ -565,11 +562,7 @@ ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
 #endif
 	while (rest_of_data > 0
 	       && (rest_of_responses > 0 || rest_of_responses == -1)
-#if ENABLE_MODEST_PARSING
 	       && interval-- > 0
-#else
-	       && (buffer_fixed || interval-- > 0)
-#endif
 	       && (eol_pos = memchr(cur_pos, '\n', rest_of_data)) != NULL)
 	  {
 	    OchushaBBSResponse response = { NULL, NULL, NULL, NULL };
@@ -604,7 +597,7 @@ ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
 		  result = (*start_thread_cb)(thread, title, callback_data);
 		G_FREE(title);
 		if (!result)
-		  break;
+		  goto terminated;
 	      }
 	    responses[i] = offset;
 
@@ -626,7 +619,7 @@ ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
 		if (rest_of_responses != -1)
 		  rest_of_responses--;
 		if (!result)
-		  break;
+		  goto terminated;
 	      }
 
 	    offset = (eol_pos + 1) - buffer_top;
@@ -655,6 +648,8 @@ ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
 	      G_FREE((gpointer)response.date_id);
 	    if (response.content != NULL)
 	      G_FREE((gpointer)response.content);
+
+	    eol_pos = NULL;
 	  }
 
 	if (!buffer_fixed && buffer->fixed)
@@ -664,8 +659,8 @@ ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
 	    continue;
 	  }
 
-	if (buffer_fixed)
-	  break;
+	if (buffer_fixed && eol_pos == NULL && interval > 0)
+	  goto terminated;
 
 	if (interval > 0)
 	  {
@@ -674,7 +669,7 @@ ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
 	     */
 	    unsigned int old_len = buffer->length;
 	    if (no_wait)
-	      break;	/* ξ */
+	      goto terminated;	/* ξ */
 
 	    if (ochusha_async_buffer_is_busy(buffer))
 	      do {
@@ -689,7 +684,6 @@ ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
 	  }
 	else
 	  {
-#if ENABLE_MODEST_PARSING
 	    if (ochusha_async_buffer_is_busy(buffer))
 	      {
 		/*
@@ -710,20 +704,6 @@ ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
 		if (!ochusha_async_buffer_wait(buffer))
 		  goto terminated;
 	      }
-#else
-	    /*
-	     * buffer˥륹åɤsuspend/terminate
-	     * ȿ뤿˥å
-	     */
-	    if (ochusha_async_buffer_is_busy(buffer)
-		&& !ochusha_async_buffer_wait(buffer))
-	      {
-#if DEBUG_ASYNC_BUFFER_MOST
-		fprintf(stderr, "ochusha_thread_jbbs_parse_responses(): buffer has been terminated.\n");
-#endif
-		break;
-	      }
-#endif
 	  }
 	interval = ANALYSIS_INTERVAL;
 
